@@ -1040,7 +1040,8 @@ cris_elf_relocate_section (output_bfd, info, input_bfd, input_section,
 		BFD_ASSERT (off != (bfd_vma) -1);
 
 		if (!elf_hash_table (info)->dynamic_sections_created
-		    || (! info->shared && h->dynindx == -1)
+		    || (! info->shared
+			&& (h->elf_link_hash_flags & ELF_LINK_HASH_DEF_REGULAR))
 		    || (info->shared
 			&& (info->symbolic || h->dynindx == -1)
 			&& (h->elf_link_hash_flags & ELF_LINK_HASH_DEF_REGULAR)))
@@ -2937,7 +2938,8 @@ elf_cris_discard_excess_program_dynamics (h, inf)
 	 functions; doing this for all symbols would presumably not
 	 introduce new problems.  Of course we don't do this if we're
 	 exporting all dynamic symbols.  */
-      if (! info->export_dynamic)
+      if (! info->export_dynamic
+	  && (h->root.elf_link_hash_flags & ELF_LINK_HASH_REF_DYNAMIC) == 0)
 	{
 	  h->root.dynindx = -1;
 	  _bfd_elf_strtab_delref (elf_hash_table (info)->dynstr,
