@@ -1613,9 +1613,15 @@ cris_return_addr_rtx (count, frameaddr)
 {
   cris_current_function_needs_return_address_on_stack = 1;
 
-  /* The return-address is stored just above the old frame pointer.  */
+  if (flag_inline_functions && count == 0)
+    sorry  ("can't get __builtin_return_address (0) right when inlining");
+
+  /* The return-address is stored just above the saved frame-pointer (if
+     present).  Apparently we can't eliminate from the frame-pointer in
+     that direction, so use the incoming args (maybe pretended) pointer.  */
   return count == 0
-    ? gen_rtx_MEM (Pmode, plus_constant (frameaddr, 4)) : NULL_RTX;
+    ? gen_rtx_MEM (Pmode, plus_constant (virtual_incoming_args_rtx, -4))
+    : NULL_RTX;
 }
 
 /* This used to be the INITIAL_FRAME_POINTER_OFFSET worker; now only
