@@ -210,7 +210,7 @@ extern int cris_next_int_is_cdtor;
    The option -shared implies -mlinux *at link-time* to cope with broken
    libtools.  */
 #define LINK_SPEC \
- "%{sim2:%{!T*:-Tdata 0x4000000 -Tbss 0x8000000}}\
+ "%{sim2|sim3:%{!T*:-Tdata 0x4000000 -Tbss 0x8000000}}\
   %{melinux:-Ur -d %{!shlib:%{!symbolic:-Bstatic}}}\
   %{melinux-stacksize=*:-defsym __Stacksize=%*}\
   %{!mlinux:%{!shared:%{!melinux:%{!maout|melf: -mcriself}}}\
@@ -236,10 +236,13 @@ extern int cris_next_int_is_cdtor;
   %{shared:%{!mlinux:-lc}}\
   %{!melinux:\
    %{!mlinux:\
-    %{!shared:%{sim*:-lc -lsyssim -lc -lsyssim}\
-     %{!sim*:%{g*:-lg}\
-       %{!p:%{!pg:-lc}}%{p:-lc_p}%{pg:-lc_p} -lbsp}\
-     -lnosys}}}"
+    %{!shared:\
+      %{sim3:--start-group -lc -lsyslinux --end-group}\
+      %{!sim3:\
+        %{sim*:-lc -lsyssim -lc -lsyssim}\
+        %{!sim*:%{g*:-lg}\
+          %{!p:%{!pg:-lc}}%{p:-lc_p}%{pg:-lc_p} -lbsp}\
+     -lnosys}}}}"
 
 /* Linker startfile options; crt0 flavors.
 
@@ -263,7 +266,7 @@ extern int cris_next_int_is_cdtor;
   %{!melinux:\
    %{!mlinux:\
     %{!shared:crtbegin2.o%s crtbegin.o%s\
-     %{sim2:s2crt0.o%s}\
+     %{sim2|sim3:s2crt0.o%s}\
      %{!sim2:%{sim:scrt0.o%s}\
       %{!sim:%{pg:gcrt0.o%s}\
        %{!pg:%{p:mcrt0.o%s}%{!p:crt0.o%s}}}}}}}"
@@ -506,7 +509,7 @@ extern int target_flags;
    with the base gcc version among users, when we ask which version of
    gcc-cris they are using.  Please use some flavor of "R<number>" for
    the version (no need for major.minor versions, I believe).  */
-#define TARGET_VERSION fprintf (stderr, " [CRIS, Axis GCC release R41]");
+#define TARGET_VERSION fprintf (stderr, " [CRIS, Axis GCC release R45]");
 
 #define OVERRIDE_OPTIONS cris_override_options ()
 
